@@ -1232,7 +1232,7 @@ def test_two_argument_useage(meth):
     ndd2 = NDDataArithmetic(np.ones((3, 3)))
 
     # Call add on the class (not the instance) and compare it with already
-    # tested useage:
+    # tested usage:
     ndd3 = getattr(NDDataArithmetic, meth)(ndd1, ndd2)
     ndd4 = getattr(ndd1, meth)(ndd2)
     np.testing.assert_array_equal(ndd3.data, ndd4.data)
@@ -1297,3 +1297,16 @@ def test_psf_warning():
         ndd2.add(ndd1)
     with pytest.warns(AstropyUserWarning, match="Not setting psf attribute during add"):
         ndd1.add(ndd1)
+
+
+def test_raise_method_not_supported():
+    ndd1 = NDDataArithmetic(np.zeros(3), uncertainty=StdDevUncertainty(np.zeros(3)))
+    ndd2 = NDDataArithmetic(np.ones(3), uncertainty=StdDevUncertainty(np.ones(3)))
+    result = np.zeros(3)
+    correlation = 0
+    # no error should be raised for supported operations:
+    ndd1.uncertainty.propagate(np.add, ndd2, result, correlation)
+
+    # raise error for unsupported propagation operations:
+    with pytest.raises(ValueError):
+        ndd1.uncertainty.propagate(np.mod, ndd2, result, correlation)
